#
# spec file for package python-mss
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without libalternatives
Name:           python-mss
Version:        7.0.1
Release:        3.1
Summary:        Python multiple screenshots module
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/BoboTiG/python-mss
Source:         https://files.pythonhosted.org/packages/source/m/mss/mss-%{version}.tar.gz
BuildRequires:  %{python_module flaky}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  lsof
BuildRequires:  python-rpm-macros
BuildRequires:  xrandr
BuildRequires:  xvfb-run
Requires:       alts
Requires:       xrandr
BuildArch:      noarch
%python_subpackages

%description
An ultra fast cross-platform multiple screenshots module in pure Python using ctypes.

%prep
%setup -q -n mss-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/mss
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%pre
%python_libalternatives_reset_alternative mss

%check
export LANG=en_US.UTF-8
# test_region_out_of_monitor_bounds fails on ppc64 only
echo '
%pytest --ignore mss/tests/test_setup.py -k "not test_region_out_of_monitor_bounds"
'> pytest_script.sh
# need explicitly set up screen.
xvfb-run --server-args "-screen 0 1920x1080x24" sh pytest_script.sh

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/mss
%{python_sitelib}/mss
%{python_sitelib}/mss-%{version}*-info

%changelog
* Mon Jun  9 2025 Markéta Machová <mmachova@suse.com>
- Convert to libalternatives
* Mon Jun  2 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Tue Nov  8 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v7.0.1
  * fixed the wheel package
- Update to v7.0.0
  * added support for Python 3.11
  * added support for Python 3.10
  * removed support for Python 3.5
  * MSS: modernized the code base (types, f-string, ran isort & black) (close #101)
  * MSS: fixed several Sourcery issues
  * MSS: fixed typos here, and there
  * doc: fixed an error when building the documentation
* Wed Dec 23 2020 Benjamin Greiner <code@bnavigator.de>
- Update to v6.1.0
  * MSS: reworked how C functions are initialised
  * tests: expand Python versions to 3.9 and 3.10
  * tests: fix test_entry_point() when there are several monitors
- clean test rig setup
* Fri Aug 14 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v6.0.0
